@@ -40,6 +40,9 @@ public:
 	/// Resync internals after select() call.
 	void sync ();
 
+	/// Return maximum value of the file descriptor in the Set
+	int  max_fd ();
+
 	/// Write current state of MaskSet object to log file. 
 	void dump ();
 };
@@ -63,6 +66,15 @@ reset ()
 	m_eset.reset ();
 }
 
+inline int
+MaskSet::
+max_fd ()
+{
+	return (std::max (m_rset.maxInSet (), 
+					  std::max (m_wset.maxInSet (), 
+								m_eset.maxInSet ())));
+}
+
 inline void 
 MaskSet::
 dump () 
